-----------------------------------------------------------------------------
--
-- To add more presets, create your own files with their data table
-- And add them into Aloft's by using:
--   Aloft:GetModule("Presets"):AddPreset(presetName, presetDataTable)
--
-- The table contains keys which are module db namespaces, and the values
-- that they override from the default
--
-- Guideline list of interrelated variables:
--  healthText: enable, mode, format
--  guildText: enable, attachFormat, attachToName, useShort, showOwn, nameText.format
--  guildText: enable, attachToName, useShort, showOwn, format
--  levelText: enable, showRace, showClassification, showCreatureType, format
--
-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AloftPresets")
L:RegisterTranslations("enUS", function() return {
	["Presets"] = true,
	["Preset configurations"] = true,

	["Default"] = true,
	["Preset 1"] = true,
	["Preset 2"] = true,
	["Preset 3"] = true,
} end)

-----------------------------------------------------------------------------

-- it's only a module so that it can be obtained via Aloft:GetModule("Presets")
local AloftPresets = Aloft:NewModule("Presets")
local presetData = { }
local lastPreset = ""

-----------------------------------------------------------------------------

Aloft.Options.args.presets =
{
	type = 'text',
	name = L["Presets"],
	desc = L["Preset configurations"],
	order = 600,
	get = function() return lastPreset end,
	set = function(v) AloftPresets:Set(v) end,
	disabled = function() return not Aloft:IsActive() end,
	validate = { },
}

-----------------------------------------------------------------------------

function AloftPresets:AddPreset(name, data)
	presetData[name] = data
	Aloft.Options.args.presets.validate[name] = name
end

local function SetKeys(db, keys)
	for k,v in pairs(keys) do
		if type(v) == "table" then
			SetKeys(db[k], v)
		else
			db[k] = v
		end
	end
end

function AloftPresets:Set(presetName)
	lastPreset = presetName

	Aloft:ResetDB("profile")

	local data = presetData[presetName]
	for namespace, keys in pairs(data) do
		local db = Aloft:AcquireDBNamespace(namespace)
		SetKeys(db.profile, keys)
	end

	Aloft:OnProfileEnable()
end

-----------------------------------------------------------------------------

local preset1 =
{
	castBar =
	{
		texture			= "Otravi",
	},
	frame =
	{
		borderStyle 	= "STANDARD",
		height			= 22,
		width			= 10,
		packingHeight	= 22,
		packingWidth	= 10,
		backgroundAlpha	= 0.5,
	},
	guildText =
	{
		enable			= true,
	},
	healthBar =
	{
		texture			= "Otravi",
		offsetY			= -6,
	},
	healthText =
	{
		enable			= true,
		mode			= "SMART",
		format			= "[not(isFriendly):health:short][not(isMaxHealth):healthPercent:hideKnownHealth:percent][isFriendly:healthDeficit:negate:hideZero:short:hexColor(\"ff8080\")]"
	},
	levelText =
	{
		offsetY				= 11,
		showCreatureType	= true,
		showClassification	= true,
		format				= "[level][shortCreatureType][shortClassification]",
	},
	nameText =
	{
		offsets =
		{
			right		= -16,
			vertical	= 12,
		},
		format			= "[name][shortGuild:prefix(\" - \")]",
	},
}

local preset2 =
{
	castBar =
	{
		texture			= "Smooth",
	},
	commentText =
	{
		enable			= true,
		shadow			= true,
		outline			= "OUTLINE",
		offsetY			= 0,
	},
	frame =
	{
		height			= 10,
		width			= 0,
		packingHeight	= 20,
		packingWidth	= 10,
		backgroundAlpha	= 0.5,
		backgroundColors =
		{
			friendlyPlayer	= { 0, 0, 0.8 },
			friendlyPet		= { 0, 0.4, 0 },
			friendlyNPC		= { 0, 0.4, 0 },
			friendlyBoss	= { 0, 0.4, 0 },
			hostilePlayer	= { 0.8, 0, 0 },
			hostilePet		= { 0.8, 0, 0 },
			hostileNPC		= { 0.8, 0, 0 },
			hostileBoss		= { 0.8, 0, 0 },
			neutral			= { 0.6, 0.6, 0 },
			pet				= { 0, 0.4, 0 },
			groupPet		= { 0, 0.4, 0 },
		},
	},
	guildText =
	{
		enable			= true,
	},
	healthBar =
	{
		texture			= "Smooth",
		offsetY			= -6,
	},
	healthText =
	{
		enable			= true,
		mode			= "SMART",
		format			= "[not(isFriendly):health:short][not(isMaxHealth):healthPercent:hideKnownHealth:percent][isFriendly:healthDeficit:negate:hideZero:short:hexColor(\"ff8080\")]"
	},
	levelText =
	{
		offsetY				= 11,
		fontShadow			= true,
		outline				= "",
		shadow				= true,
		showCreatureType	= true,
		showClassification	= true,
		format				= "[level][shortCreatureType][shortClassification]",
	},
	nameText =
	{
		outline			= "",
		shadow			= true,
		offsets =
		{
			right		= -16,
			vertical	= 11,
		},
		format			= "[name][shortGuild:prefix(\" - \")]",
	},
}

local preset3 =
{
	castBar =
	{
		texture			= "Charcoal",
	},
	commentText =
	{
		enable			= true,
		shadow			= true,
		outline			= "OUTLINE",
		offsetY			= 0,
	},
	guildText =
	{
		enable			= true,
	},
	healthBar =
	{
		texture			= "Charcoal",
	},
	levelText =
	{
		enable			= false,
	},
	nameText =
	{
		outline			= "OUTLINE",
		shadow			= true,
		alignment		= "CENTER",
		offsets =
		{
			vertical	= 11,
		},
		format			= "[name][shortGuild:prefix(\" - \")]",
	},
}

-----------------------------------------------------------------------------

AloftPresets:AddPreset(L["Default"], { })
AloftPresets:AddPreset(L["Preset 1"], preset1)
AloftPresets:AddPreset(L["Preset 2"], preset2)
AloftPresets:AddPreset(L["Preset 3"], preset3)

-----------------------------------------------------------------------------
